/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     SAS Institute Inc. - adapted original snippet to use Albireo API
 *******************************************************************************/
package org.eclipse.albireo.examples;

import java.util.Vector;

import javax.swing.JComponent;
import javax.swing.JScrollPane;
import javax.swing.JTable;

import org.eclipse.albireo.core.SwingControl;
import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.layout.FillLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Shell;

/*
 * example snippet: embed a JTable in SWT (no flicker) using Albireo
 *
 * A version of SWT Snippet 154, changed to use Albireo. 
 * 
 * For a list of all SWT example snippets see
 * http://www.eclipse.org/swt/snippets/
 * 
 * @since 3.0
 */
public class EmbeddedJTable {

    /**
     * @param args
     */
    public static void main(String[] args) {
        final Display display = new Display();
        final Shell shell = new Shell(display);
        shell.setLayout(new FillLayout());

        SwingControl control = new SwingControl(shell, SWT.NONE) {
            protected JComponent createSwingComponent() {
                return createTable();
            }

            public Composite getLayoutAncestor() {
                return shell;
            }
        };
        
        shell.open();
        while(!shell.isDisposed()) {
            if (!display.readAndDispatch()) display.sleep();
        }
        display.dispose();
    }

    private static JComponent createTable() {
        /* Creating components */
        int nrows = 1000, ncolumns = 10;
        Vector rows = new Vector();
        for (int i = 0; i < nrows; i++) {
            Vector row = new Vector();
            for (int j = 0; j < ncolumns; j++) {
                row.addElement("Item " + i + "-" + j);
            }
            rows.addElement(row);
        }
        Vector columns = new Vector();
        for (int i = 0; i < ncolumns; i++) {
            columns.addElement("Column " + i);
        }
        JTable table = new JTable(rows, columns);
        table.setAutoResizeMode(JTable.AUTO_RESIZE_OFF);
        table.createDefaultColumnsFromModel();
        JScrollPane scrollPane = new JScrollPane(table);
        return scrollPane;
    }

}
